package cz.jzitnik.chronos.controllers;

import cz.jzitnik.chronos.payload.errors.NotFoundError;
import cz.jzitnik.chronos.payload.requests.PlayerNameRequest;
import cz.jzitnik.chronos.payload.responses.UnifiedResponse;
import cz.jzitnik.chronos.repository.GameRepository;
import cz.jzitnik.chronos.repository.PlayerRepository;
import cz.jzitnik.chronos.services.GameService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;

@CrossOrigin(origins = "*", maxAge = 3600)
@RestController
@RequestMapping("/game/players")
public class PlayerController {
    @Autowired
    private GameRepository gameRepository;

    @Autowired
    private PlayerRepository playerRepository;

    @Autowired
    private GameService gameService;

    @PostMapping("/new")
    public ResponseEntity<UnifiedResponse<String, Error>> newPlayer(@RequestParam String gameKey, @RequestBody PlayerNameRequest playerNameRequest) {
        var gameOptional = gameRepository.findByGameKey(gameKey);

        if (gameOptional.isEmpty()) {
            return ResponseEntity.status(HttpStatus.NOT_FOUND).body(
                UnifiedResponse.failure(new NotFoundError("Game with key " + gameKey + " was not found!"))
            );
        }

        var game = gameOptional.get();

        var player = gameService.addPlayer(game, playerNameRequest.getName());

        gameRepository.save(game);

        return ResponseEntity.ok(
                UnifiedResponse.success(player.getPlayerKey())
        );
    }
}
