package cz.jzitnik.chronos.payload.responses;

import lombok.Getter;
import lombok.Setter;

import java.util.Optional;

public class UnifiedResponse<T, U> {
    @Getter
    private final Optional<T> data;

    @Getter
    private final Optional<U> error;

    @Getter
    private final Boolean success;

    private UnifiedResponse(Optional<T> data, Optional<U> error, Boolean success) {
        this.data = data;
        this.error = error;
        this.success = success;
    }

    public static <T, U> UnifiedResponse<T, U> success(T data) {
        return new UnifiedResponse<>(Optional.ofNullable(data), Optional.empty(), true);
    }

    // Static factory method for error response
    public static <T, U> UnifiedResponse<T, U> failure(U error) {
        return new UnifiedResponse<>(Optional.empty(), Optional.ofNullable(error), false);
    }

    // Static factory method for empty response
    public static <T, U> UnifiedResponse<T, U> empty() {
        return new UnifiedResponse<>(Optional.empty(), Optional.empty(), false);
    }
}
